@@ -90,8 +90,6 @@ struct _TrackerDecoratorPrivate {
 	GTimer *timer;
 	GQueue next_elem_queue; /* Queue of incoming tasks */
 
-	GCancellable *cancellable;
-
 	gint batch_size;
 
 	guint processing : 1;
@@ -431,7 +429,7 @@ decorator_commit_info (TrackerDecorator *decorator)
 	                                              (gchar **) array->pdata,
 	                                              array->len,
 	                                              G_PRIORITY_DEFAULT,
-						      priv->cancellable,
+	                                              NULL,
 	                                              decorator_commit_cb,
 	                                              decorator);
 
@@ -792,6 +790,8 @@ decorator_query_remaining_items_cb (GObject      *object,
 
 	cursor = tracker_sparql_connection_query_finish (TRACKER_SPARQL_CONNECTION (object),
 							 result, &error);
+	priv = decorator->priv;
+        priv->querying = FALSE;
 
 	if (error || !tracker_sparql_cursor_next (cursor, NULL, &error)) {
 		decorator_notify_task_error (decorator, error);
@@ -799,14 +799,11 @@ decorator_query_remaining_items_cb (GObject      *object,
 		return;
 	}
 
-	priv = decorator->priv;
-	priv->querying = FALSE;
-
 	priv->n_remaining_items = g_queue_get_length (&priv->item_cache) +
 		tracker_sparql_cursor_get_integer (cursor, 0);
 	g_object_unref (cursor);
 
-	g_debug ("Found %ld items to extract", priv->n_remaining_items);
+	g_debug ("Found %" G_GSIZE_FORMAT " items to extract", priv->n_remaining_items);
 
 	if (priv->n_remaining_items > 0)
 		decorator_cache_next_items (decorator);
@@ -819,16 +816,13 @@ decorator_query_remaining_items (TrackerDecorator *decorator)
 {
 	gchar *query, *clauses[] = { "COUNT(?urn)", NULL };
 	TrackerSparqlConnection *sparql_conn;
-	TrackerDecoratorPrivate *priv;
 
-	priv = decorator->priv;
 	query = create_query_string (decorator, clauses, FALSE);
 
 	if (query) {
 		sparql_conn = tracker_miner_get_connection (TRACKER_MINER (decorator));
 		tracker_sparql_connection_query_async (sparql_conn, query,
-						       priv->cancellable,
-		                                       decorator_query_remaining_items_cb,
+		                                       NULL, decorator_query_remaining_items_cb,
 		                                       decorator);
 		g_free (query);
 	} else {
@@ -937,8 +931,7 @@ decorator_cache_next_items (TrackerDecorator *decorator)
 		sparql_conn = tracker_miner_get_connection (TRACKER_MINER (decorator));
 		query = create_remaining_items_query (decorator);
 		tracker_sparql_connection_query_async (sparql_conn, query,
-						       priv->cancellable,
-						       decorator_cache_items_cb,
+						       NULL, decorator_cache_items_cb,
 						       decorator);
 		g_free (query);
 	}
@@ -1141,9 +1134,6 @@ tracker_decorator_finalize (GObject *object)
 	decorator = TRACKER_DECORATOR (object);
 	priv = decorator->priv;
 
-	g_cancellable_cancel (priv->cancellable);
-	g_clear_object (&priv->cancellable);
-
 	g_clear_object (&priv->notifier);
 
 	g_queue_foreach (&priv->item_cache,
@@ -1312,7 +1302,6 @@ tracker_decorator_init (TrackerDecorator *decorator)
 	priv->prepended_ids = g_array_new (FALSE, FALSE, sizeof (gint));
 	priv->batch_size = DEFAULT_BATCH_SIZE;
 	priv->timer = g_timer_new ();
-	priv->cancellable = g_cancellable_new ();
 
 	g_queue_init (&priv->next_elem_queue);
 	g_queue_init (&priv->item_cache);
