@@ -29,7 +29,6 @@
 #include <libtracker-data/tracker-data.h>
 
 static gchar *tests_data_dir = NULL;
-static gchar *xdg_location = NULL;
 static gint backup_calls = 0;
 static GMainLoop *loop = NULL;
 
@@ -38,6 +37,7 @@ typedef struct _TestInfo TestInfo;
 struct _TestInfo {
 	const gchar *test_name;
 	gboolean use_journal;
+	gchar *data_location;
 };
 
 const TestInfo tests[] = {
@@ -60,8 +60,9 @@ backup_finished_cb (GError   *error,
 }
 
 static gboolean
-check_content_in_db (gint expected_instances,
-                     gint expected_relations)
+check_content_in_db (TrackerDataManager *manager,
+                     gint                expected_instances,
+                     gint                expected_relations)
 {
 	GError *error = NULL;
 	const gchar  *query_instances_1 = "SELECT ?u WHERE { ?u a foo:class1. }";
@@ -69,7 +70,7 @@ check_content_in_db (gint expected_instances,
 	TrackerDBCursor *cursor;
 	gint n_rows;
 
-	cursor = tracker_data_query_sparql_cursor (query_instances_1, &error);
+	cursor = tracker_data_query_sparql_cursor (manager, query_instances_1, &error);
 	g_assert_no_error (error);
 	n_rows = 0;
 	while (tracker_db_cursor_iter_next (cursor, NULL, &error)) {
@@ -79,7 +80,7 @@ check_content_in_db (gint expected_instances,
 	g_assert_cmpint (n_rows, ==, expected_instances);
 	g_object_unref (cursor);
 
-	cursor = tracker_data_query_sparql_cursor (query_relation, &error);
+	cursor = tracker_data_query_sparql_cursor (manager, query_relation, &error);
 	g_assert_no_error (error);
 	n_rows = 0;
 	while (tracker_db_cursor_iter_next (cursor, NULL, &error)) {
@@ -101,40 +102,43 @@ check_content_in_db (gint expected_instances,
  * Run again the queries
  */
 static void
-test_backup_and_restore_helper (gboolean journal)
+test_backup_and_restore_helper (const gchar *db_location,
+                                gboolean     journal)
 {
-	gchar  *data_prefix, *data_filename, *backup_location, *backup_filename, *db_location, *meta_db;
+	gchar  *data_prefix, *data_filename, *backup_location, *backup_filename, *meta_db, *ontologies;
 	GError *error = NULL;
 	GFile  *backup_file;
-	gchar *test_schemas[5] = { NULL, NULL, NULL, NULL, NULL };
+	GFile  *data_location, *test_schemas;
+	TrackerDataManager *manager;
+	TrackerData *data_update;
+
+	data_location = g_file_new_for_path (db_location);
 
-	db_location = g_build_path (G_DIR_SEPARATOR_S, xdg_location, "tracker", NULL);
 	data_prefix = g_build_path (G_DIR_SEPARATOR_S, 
 	                            TOP_SRCDIR, "tests", "libtracker-data", "backup", "backup",
 	                            NULL);
 
-	/*
-	 * This function uses $(data_prefix).ontology
-	 */ 
-	test_schemas[0] = g_build_path (G_DIR_SEPARATOR_S, TOP_SRCDIR, "tests", "libtracker-data", "ontologies", "20-dc", NULL);
-	test_schemas[1] = g_build_path (G_DIR_SEPARATOR_S, TOP_SRCDIR, "tests", "libtracker-data", "ontologies", "31-nao", NULL);
-	test_schemas[2] = g_build_path (G_DIR_SEPARATOR_S, TOP_SRCDIR, "tests", "libtracker-data", "ontologies", "90-tracker", NULL);
-	test_schemas[3] = data_prefix;
+	ontologies = g_build_path (G_DIR_SEPARATOR_S,
+	                           TOP_SRCDIR, "tests", "libtracker-data", "backup",
+	                           NULL);
+	test_schemas = g_file_new_for_path (ontologies);
 
 	tracker_db_journal_set_rotating (FALSE, G_MAXSIZE, NULL);
 
-	tracker_data_manager_init (TRACKER_DB_MANAGER_FORCE_REINDEX,
-	                           (const gchar **) test_schemas,
-	                           NULL, FALSE, FALSE,
-	                           100, 100, NULL, NULL, NULL, &error);
-
+	manager = tracker_data_manager_new (TRACKER_DB_MANAGER_FORCE_REINDEX,
+	                                    data_location, data_location, test_schemas,
+	                                    FALSE, FALSE, 100, 100);
+	g_initable_init (G_INITABLE (manager), NULL, &error);
 	g_assert_no_error (error);
 
 	/* load data set */
 	data_filename = g_strconcat (data_prefix, ".data", NULL);
 	if (g_file_test (data_filename, G_FILE_TEST_IS_REGULAR)) {
-		tracker_turtle_reader_load (data_filename, &error);
+		GFile *file = g_file_new_for_path (data_filename);
+		data_update = tracker_data_manager_get_data (manager);
+		tracker_turtle_reader_load (file, data_update, &error);
 		g_assert_no_error (error);
+		g_object_unref (file);
 	} else {
 		g_assert_not_reached ();
 	}
@@ -142,7 +146,7 @@ test_backup_and_restore_helper (gboolean journal)
 
 
 	/* Check everything is correct */
-	check_content_in_db (3, 1);
+	check_content_in_db (manager, 3, 1);
 
 	backup_location = g_build_filename (db_location, "backup", NULL);
 	g_mkdir (backup_location, 0777);
@@ -150,7 +154,9 @@ test_backup_and_restore_helper (gboolean journal)
 	backup_file = g_file_new_for_path (backup_filename);
 	g_free (backup_filename);
 	g_free (backup_location);
-	tracker_data_backup_save (backup_file,
+	tracker_data_backup_save (manager,
+	                          backup_file,
+				  data_location,
 	                          backup_finished_cb,
 	                          NULL,
 	                          NULL);
@@ -161,7 +167,7 @@ test_backup_and_restore_helper (gboolean journal)
 	g_main_loop_unref (loop);
 	loop = NULL;
 
-	tracker_data_manager_shutdown ();
+	g_object_unref (manager);
 
 	meta_db = g_build_path (G_DIR_SEPARATOR_S, db_location, "meta.db", NULL);
 	g_unlink (meta_db);
@@ -187,39 +193,31 @@ test_backup_and_restore_helper (gboolean journal)
 	tracker_db_journal_set_rotating (FALSE, G_MAXSIZE, NULL);
 #endif /* DISABLE_JOURNAL */
 
-	tracker_data_manager_init (TRACKER_DB_MANAGER_FORCE_REINDEX,
-	                           (const gchar **) test_schemas,
-	                           NULL, FALSE, FALSE,
-	                           100, 100, NULL, NULL, NULL, &error);
-
+	manager = tracker_data_manager_new (TRACKER_DB_MANAGER_FORCE_REINDEX,
+	                                    data_location, data_location, test_schemas,
+	                                    FALSE, FALSE, 100, 100);
+	g_initable_init (G_INITABLE (manager), NULL, &error);
 	g_assert_no_error (error);
 
-	check_content_in_db (0, 0);
+	check_content_in_db (manager, 0, 0);
 
-	tracker_data_backup_restore (backup_file, (const gchar **) test_schemas, NULL, NULL, &error);
+	tracker_data_backup_restore (manager, backup_file, data_location, data_location, test_schemas, NULL, NULL, &error);
 	g_assert_no_error (error);
-	check_content_in_db (3, 1);
+	check_content_in_db (manager, 3, 1);
 
-	g_free (test_schemas[0]);
-	g_free (test_schemas[1]);
-	g_free (test_schemas[2]);
-	g_free (test_schemas[3]);
+	g_object_unref (test_schemas);
+	g_free (ontologies);
 
 	g_assert_cmpint (backup_calls, ==, 1);
 
-	tracker_data_manager_shutdown ();
+	g_object_unref (manager);
 }
 
 static void
 test_backup_and_restore (TestInfo      *info,
                          gconstpointer  context)
 {
-	gint index;
-
-	index = GPOINTER_TO_INT (context);
-	*info = tests[index];
-
-	test_backup_and_restore_helper (info->use_journal);
+	test_backup_and_restore_helper (info->data_location, info->use_journal);
 	backup_calls = 0;
 }
 
@@ -227,27 +225,15 @@ static void
 setup (TestInfo      *info,
        gconstpointer  context)
 {
-	gint i;
+	const TestInfo *test = context;
+	gchar *basename;
 
-	i = GPOINTER_TO_INT (context);
-	*info = tests[i];
+	*info = *test;
 
-	/* Sadly, we can't use ONE location per test because GLib
-	 * caches XDG env vars, so g_get_*dir() will not change if we
-	 * update the environment, this sucks majorly.
-	 */
-	if (!xdg_location) {
-		gchar *basename;
-
-		/* NOTE: g_test_build_filename() doesn't work env vars G_TEST_* are not defined?? */
-		basename = g_strdup_printf ("%d", g_test_rand_int_range (0, G_MAXINT));
-		xdg_location = g_build_path (G_DIR_SEPARATOR_S, tests_data_dir, basename, NULL);
-		g_free (basename);
-
-		g_assert_true (g_setenv ("XDG_DATA_HOME", xdg_location, TRUE));
-		g_assert_true (g_setenv ("XDG_CACHE_HOME", xdg_location, TRUE));
-		g_assert_true (g_setenv ("TRACKER_DB_ONTOLOGIES_DIR", TOP_SRCDIR "/src/ontologies/", TRUE));
-	}
+	/* NOTE: g_test_build_filename() doesn't work env vars G_TEST_* are not defined?? */
+	basename = g_strdup_printf ("%d", g_test_rand_int_range (0, G_MAXINT));
+	info->data_location = g_build_path (G_DIR_SEPARATOR_S, tests_data_dir, basename, NULL);
+	g_free (basename);
 }
 
 static void
@@ -257,14 +243,13 @@ teardown (TestInfo      *info,
 	gchar *cleanup_command;
 
 	/* clean up */
-	g_print ("Removing temporary data (%s)\n", xdg_location);
+	g_print ("Removing temporary data (%s)\n", info->data_location);
 
-	cleanup_command = g_strdup_printf ("rm -Rf %s/", xdg_location);
+	cleanup_command = g_strdup_printf ("rm -Rf %s/", info->data_location);
 	g_spawn_command_line_sync (cleanup_command, NULL, NULL, NULL, NULL);
 	g_free (cleanup_command);
 
-	g_free (xdg_location);
-	xdg_location = NULL;
+	g_free (info->data_location);
 }
 
 int
@@ -281,8 +266,8 @@ main (int argc, char **argv)
 
 	g_test_init (&argc, &argv, NULL);
 
-	g_test_add ("/libtracker-data/backup/journal_then_save_and_restore", TestInfo, GINT_TO_POINTER(0), setup, test_backup_and_restore, teardown);
-	g_test_add ("/libtracker-data/backup/save_and_restore", TestInfo, GINT_TO_POINTER(1), setup, test_backup_and_restore, teardown);
+	g_test_add ("/libtracker-data/backup/journal_then_save_and_restore", TestInfo, &tests[0], setup, test_backup_and_restore, teardown);
+	g_test_add ("/libtracker-data/backup/save_and_restore", TestInfo, &tests[1], setup, test_backup_and_restore, teardown);
 
 	result = g_test_run ();
 
